@@ -146,7 +146,7 @@ class _ExpandingRollingMechanism:
         if t is not None:
             self.t = t
         else :
-            self.t = self.s
+            self.t = 3 * self.s
         # Set max index
         if T is None:
             self.T = self.idx.size
